#!/bin/bash

# Function to generate SHA-256 hashes for .sh files in the src directory
calculate_hashes() {
  local src_dir="./src"

  # Check if the directory exists
  if [ ! -d "$src_dir" ]; then
    echo "Directory $src_dir does not exist."
    return 1
  fi

  # Determine the command to use for calculating SHA-256
  local hash_cmd
  if command -v sha256sum >/dev/null 2>&1; then
    hash_cmd=("sha256sum")
  elif command -v shasum >/dev/null 2>&1; then
    hash_cmd=("shasum" "-a" "256")
  else
    echo "Neither sha256sum nor shasum command is available."
    return 1
  fi

  echo "Using hash command: ${hash_cmd[*]}"

  # Loop through all .sh files in the directory
  for file in "$src_dir"/*.sh; do
    # Skip if no .sh files are found
    [ -e "$file" ] || continue

    # Print the file being processed for debugging
    echo "Processing file: $file"

    # Calculate the SHA-256 hash and save it to a .sha256 file
    result=$("${hash_cmd[@]}" "$file" 2>&1)
    if [ $? -ne 0 ]; then
      echo "Failed to execute ${hash_cmd[*]} for $file: $result"
      continue
    fi

    echo "$result" | awk '{ print $1 }' > "$file.sha256"
  done

  echo "SHA-256 hashes have been saved in .sha256 files."
}

